@@ -37,11 +37,19 @@ sub run {
     # Only for non-cdbs packages
     return if $info->relation('build-depends-all')->implies('cdbs');
 
-    # Module::Build::Tiny and debhelper version 9.20140227
+    # arch:any and debhelper version 9.20120312
+    if ( $info->field('architecture') ne 'all'
+        && !$info->relation('build-depends')
+        ->implies('debhelper (>= 9.20120312~)') )
+    {
+        tag 'arch-any-package-needs-newer-debhelper';
+    }
+
+    # Module::Build::Tiny and debhelper version 9.20130630
     if ( $info->relation('build-depends-all')
         ->implies('libmodule-build-tiny-perl')
         && !$info->relation('build-depends')
-        ->implies('debhelper (>= 9.20140227~)') )
+        ->implies('debhelper (>= 9.20130630~)') )
     {
         tag 'module-build-tiny-needs-newer-debhelper';
     }
